# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/asto',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/asto',
                'lib_path': 'asto'},
  'syms': { 'asto.arrs': { 'asto.arrs.ann2arr': ('arrs.html#ann2arr', 'asto/arrs.py'),
                           'asto.arrs.arrchain': ('arrs.html#arrchain', 'asto/arrs.py'),
                           'asto.arrs.as01': ('arrs.html#as01', 'asto/arrs.py'),
                           'asto.arrs.asarr': ('arrs.html#asarr', 'asto/arrs.py'),
                           'asto.arrs.chain': ('arrs.html#chain', 'asto/arrs.py'),
                           'asto.arrs.clone': ('arrs.html#clone', 'asto/arrs.py'),
                           'asto.arrs.cpu': ('arrs.html#cpu', 'asto/arrs.py'),
                           'asto.arrs.detach': ('arrs.html#detach', 'asto/arrs.py'),
                           'asto.arrs.dns2arr': ('arrs.html#dns2arr', 'asto/arrs.py'),
                           'asto.arrs.mth2arr': ('arrs.html#mth2arr', 'asto/arrs.py'),
                           'asto.arrs.mtx2arr': ('arrs.html#mtx2arr', 'asto/arrs.py'),
                           'asto.arrs.nparray': ('arrs.html#nparray', 'asto/arrs.py'),
                           'asto.arrs.numpy': ('arrs.html#numpy', 'asto/arrs.py'),
                           'asto.arrs.spr2arr': ('arrs.html#spr2arr', 'asto/arrs.py'),
                           'asto.arrs.toarray': ('arrs.html#toarray', 'asto/arrs.py'),
                           'asto.arrs.todense': ('arrs.html#todense', 'asto/arrs.py'),
                           'asto.arrs.tolist': ('arrs.html#tolist', 'asto/arrs.py'),
                           'asto.arrs.trc2arr': ('arrs.html#trc2arr', 'asto/arrs.py'),
                           'asto.arrs.try2arr': ('arrs.html#try2arr', 'asto/arrs.py')},
            'asto.time': { 'asto.time.day2hours': ('time.html#day2hours', 'asto/time.py'),
                           'asto.time.day2hrs': ('time.html#day2hrs', 'asto/time.py')}}}



__version__ = "0.0.3"
# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00__init__.ipynb.

# %% auto 0
__all__ = ['lib', 'mods', 'modules']

# %% ../nbs/00__init__.ipynb 3
from mstar import expose
lib, mods = 'asto', ('arrs', 'time', )
modules, __all__ = expose(lib, *mods, scope=globals())
